"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.httpRequest = httpRequest;
exports.getFromSimple = getFromSimple;
exports.isValueValid = isValueValid;
exports.removeTag = removeTag;
const lodash_1 = require("lodash");
function httpRequest(request_1, uri_1) {
    return __awaiter(this, arguments, void 0, function* (request, uri, init = {}) {
        const controller = new AbortController();
        const abortTimeout = setTimeout(() => controller.abort(), 1000 * 15);
        return request(uri, Object.assign(Object.assign({}, init), { signal: controller.signal }))
            .then((res) => __awaiter(this, void 0, void 0, function* () {
            const res1 = res.clone();
            const results = yield Promise.all([res.json(), res1.text()]);
            if (results[0] != null) {
                return results[0];
            }
            return results[1] || undefined;
        }))
            .catch(() => {
            clearTimeout(abortTimeout);
            return undefined;
        });
    });
}
const providerMapping = {
    trovo: {
        game: 'category_name',
        name: 'username',
        title: 'live_title',
    },
    twitch: {
        game: 'game_name',
        name: 'broadcaster_name',
        title: 'title',
    },
    picarto: {
        game: 'category[0]',
        name: 'name',
        title: 'title',
    },
    kick: {
        game: [
            'livestream.categories[0].name',
            'recent_categories[0].name',
        ],
        title: [
            'livestream.session_title',
            'previous_livestreams[0].session_title',
        ],
        name: 'user.username',
    },
};
function getFromSimple(provider, toPick) {
    if (providerMapping[provider.toLowerCase()] === undefined) {
        throw TypeError('Invalid Provider.');
    }
    if (providerMapping[provider.toLowerCase()][toPick.toLowerCase()] === undefined) {
        return toPick;
    }
    return providerMapping[provider.toLowerCase()][toPick.toLowerCase()];
}
function isValueValid(value) {
    if ((0, lodash_1.isArray)(value) || (0, lodash_1.isObject)(value) || value === null) {
        return false;
    }
    return true;
}
function removeTag(user) {
    if (user == null) {
        return '';
    }
    return user.replace('#', '')
        .replace('@', '');
}
//# sourceMappingURL=helpers.js.map