"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.methods = void 0;
exports.charity = charity;
const config = require("config");
function getCurrency(currency) {
    switch (currency.toLowerCase()) {
        case 'usd':
            return '$';
        case 'gbp':
            return '£';
        default:
            return currency;
    }
}
exports.methods = {
    twitch: (parser, _request, channelId, coreId, serviceId, field) => __awaiter(void 0, void 0, void 0, function* () {
        var _a;
        if (((_a = parser === null || parser === void 0 ? void 0 : parser.middleware) === null || _a === void 0 ? void 0 : _a.onServiceAPI) == null) {
            return '[Error: API Error]';
        }
        const res = yield parser.middleware.onServiceAPI(`${config.get('providers.twitch.urls.api')}/helix/charity/campaigns?broadcaster_id=${channelId}`, {
            coreId,
            method: 'GET',
            serviceId,
        });
        if (res == null) {
            return '[Error: API Error]';
        }
        if (res.total === 0 || res.data.length === 0) {
            return '[Error: No campaign active]';
        }
        const data = res.data[0];
        const currency = getCurrency(data['current_amount']['currency']);
        const currAmount = Number(data['current_amount']['value']);
        const decimalPlaces = data['current_amount']['decimal_places'] || 2;
        const goalAmount = Number(data['target_amount']['value']);
        if (field != null) {
            switch (field.toLowerCase()) {
                case 'raised':
                    return `${currency}${currAmount.toFixed(decimalPlaces)}`;
                case 'description':
                    return data['charity_description'];
                case 'name':
                    return data['charity_name'];
                case 'progress':
                    return `${(currAmount / goalAmount) * 100}%`;
                case 'remaining':
                    return `${currency}${(goalAmount - currAmount).toFixed(decimalPlaces)}`;
                case 'target':
                    return `${currency}${goalAmount.toFixed(decimalPlaces)}`;
                case 'website':
                    return data['charity_website'];
                default:
                    break;
            }
        }
        return `${data['charity_name']}: ${data['charity_description']} - ${data['charity_website']}`;
    }),
};
function charity(message, _settings, { request }, field = null) {
    if (exports.methods[message.provider.toLowerCase()] == null) {
        return '[Error: Invalid Provider]';
    }
    return exports.methods[message.provider.toLowerCase()](this, request, message.channel.id, message.channel.coreId, message.channel.serviceId, field);
}
//# sourceMappingURL=charity.js.map