"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.extralife = extralife;
exports.parseNum = parseNum;
const lodash_1 = require("lodash");
const helpers_1 = require("../lib/helpers");
function extralife(_message_1, _settings_1, _a, id_1) {
    return __awaiter(this, arguments, void 0, function* (_message, _settings, { request }, id, type = 'all') {
        const req = yield (0, helpers_1.httpRequest)(request, `https://www.extra-life.org/api/participants/${id}`);
        if (req === undefined || req.length === 0 || (0, lodash_1.isString)(req)) {
            return '[Error: API Error]';
        }
        try {
            switch (type.toLowerCase()) {
                case 'goal':
                    return parseNum(req.fundraisingGoal);
                case 'raised':
                    return parseNum(req.sumDonations);
                case 'total':
                    return `${parseNum(req.sumDonations)} (${totalPercentage(req.fundraisingGoal, req.sumDonations)}%)`;
                case 'all':
                default:
                    return `Raised: ${parseNum(req.sumDonations)} Goal: ${parseNum(req.fundraisingGoal)} (${totalPercentage(req.fundraisingGoal, req.sumDonations)}%)`;
            }
        }
        catch (err) {
            return '[Error: Internal Error]';
        }
    });
}
function parseNum(num, thou = ',', dec = '.', sym = '$') {
    return num.toFixed(2)
        .toString()
        .split(/[-.]/)
        .reverse()
        .reduceRight((t, c, i) => {
        return (i === 1) ? t + c.replace(/(\d)(?=(\d{3})+$)/g, `$1${thou}`) : t + dec + c;
    }, sym);
}
function totalPercentage(total, current) {
    return Math.trunc(((100 * current) / total));
}
//# sourceMappingURL=extralife.js.map