"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.methods = void 0;
exports.followage = followage;
const config = require("config");
const countdown = require("countdown");
const lodash_1 = require("lodash");
const moment = require("moment");
const helpers_1 = require("../lib/helpers");
exports.methods = {
    twitch: (parser, _request, channelId, userId, coreId, serviceId) => __awaiter(void 0, void 0, void 0, function* () {
        const res = yield parser.middleware.onServiceAPI(`${config.get('providers.twitch.urls.api')}/helix/channels/followers?user_id=${userId}&broadcaster_id=${channelId}`, {
            coreId,
            method: 'GET',
            serviceId,
        });
        if (res == null) {
            return {
                error: '[Error: API Error]',
                following: false,
                following_since: null,
            };
        }
        if (res.total === 0 || res.data.length === 0) {
            return {
                following: false,
                following_since: null,
            };
        }
        return {
            following: true,
            following_since: countdown(new Date(), moment(res.data[0].followed_at).toDate()).toString(),
        };
    }),
    kick: (_parser, request, channelId, userName, _coreId, _serviceId) => __awaiter(void 0, void 0, void 0, function* () {
        const headers = {
            'Content-Type': 'application/json',
            'Accept': 'application/json',
        };
        const res = yield (0, helpers_1.httpRequest)(request, `${config.get('providers.kick.urls.api')}/v1/channels/${String(channelId).toLowerCase()}/users/${String(userName).toLowerCase()}`, { headers });
        if (res == null) {
            return {
                error: '[Error: API Error]',
                following: false,
                following_since: null,
            };
        }
        if (res.following_since == null) {
            return {
                following: false,
                following_since: null,
            };
        }
        return {
            following: true,
            following_since: countdown(new Date(), moment(res.following_since).toDate()).toString(),
        };
    }),
    trovo: (_parser, request, channelId, userId) => __awaiter(void 0, void 0, void 0, function* () {
        let foundFollower = false;
        const headers = {
            'Client-ID': config.get('providers.trovo.clientId'),
        };
        const payload = {
            limit: 100,
            cursor: 0,
        };
        while (!foundFollower) {
            const res = yield (0, helpers_1.httpRequest)(request, `${config.get('providers.trovo.urls.api')}/openplatform/channels/${channelId}/followers`, { headers, method: 'POST', body: JSON.stringify(payload) });
            if (res == null || (0, lodash_1.isString)(res)) {
                break;
            }
            for (const follower of res.follower) {
                if (follower.user_id === userId) {
                    foundFollower = true;
                    return {
                        following: true,
                        following_since: countdown(new Date(), moment(follower.followed_at).utc().toDate()).toString(),
                    };
                }
            }
            payload.cursor = res.cursor;
            yield new Promise(resolve => setTimeout(resolve, 500));
        }
        return {
            following: false,
            following_since: null,
        };
    }),
};
function followage(message_1, _settings_1, _a) {
    return __awaiter(this, arguments, void 0, function* (message, _settings, { request }) {
        if (exports.methods[message.provider.toLowerCase()] == null) {
            return '[Error: Invalid Provider]';
        }
        try {
            let userFollowing = null;
            if (['kick'].includes(message.provider.toLowerCase())) {
                userFollowing = yield exports.methods[message.provider.toLowerCase()](this, request, message.channel.name, message.user.name, message.channel.coreId, message.channel.serviceId);
            }
            else {
                userFollowing = yield exports.methods[message.provider.toLowerCase()](this, request, message.channel.id, message.user.id, message.channel.coreId, message.channel.serviceId);
            }
            if (userFollowing.error != null) {
                return userFollowing.error;
            }
            if (!userFollowing.following) {
                return `@${message.user.name}, you are not following the channel.`;
            }
            return `@${message.user.name}, you have been following for ${userFollowing.following_since}.`;
        }
        catch (err) {
            return '[Error: API Error]';
        }
    });
}
//# sourceMappingURL=followage.js.map