"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.mastodon = mastodon;
const config = require("config");
const countdown = require("countdown");
const lodash_1 = require("lodash");
const moment = require("moment");
const util_1 = require("util");
const helpers_1 = require("../lib/helpers");
const BASE_SEARCH_URL = '%s/api/v2/search?type=accounts&resolve=true&q=%s&limit=1';
const BASE_STATUSES_URL = '%s/api/v1/accounts/%s/statuses?exclude_replies=true&limit=1';
function mastodon(_message_1, _settings_1, _a, account_1) {
    return __awaiter(this, arguments, void 0, function* (_message, _settings, { request }, account, type = 'text') {
        const headers = {
            Authorization: `Bearer ${config.get('parser.mastodon.key')}`,
        };
        const SEARCH_URL = (0, util_1.format)(BASE_SEARCH_URL, config.get('parser.mastodon.base'), account);
        const userAccount = yield (0, helpers_1.httpRequest)(request, SEARCH_URL, { headers });
        if (userAccount == null || (0, lodash_1.isString)(userAccount)) {
            return '[Error: API Error]';
        }
        if (userAccount.accounts.length === 0) {
            return '[Error: Invalid Account]';
        }
        const STATUSES_URL = (0, util_1.format)(BASE_STATUSES_URL, config.get('parser.mastodon.base'), userAccount.accounts[0].id);
        const statuses = yield (0, helpers_1.httpRequest)(request, STATUSES_URL);
        if (statuses == null || (0, lodash_1.isString)(statuses)) {
            return '[Error: API Error]';
        }
        if (statuses.length === 0) {
            return '[Error: No Statuses]';
        }
        const status = statuses[0];
        if (type === 'link') {
            return status.url;
        }
        const contentShort = (0, lodash_1.truncate)(status.content.replace(/(<([^>]+)>)/gi, ''), { length: 100 });
        const timeSince = `${countdown(new Date(), moment(status.created_at).toDate()).toString()} ago`;
        return `${(0, lodash_1.unescape)(contentShort)} - ${status.url} | ${timeSince}`;
    });
}
//# sourceMappingURL=mastodon.js.map