"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.rainwave = rainwave;
const lodash_1 = require("lodash");
const querystring_1 = require("querystring");
const helpers_1 = require("../lib/helpers");
const RadioMap = {
    game: 1,
    ocremix: 2,
    covers: 3,
    chiptunes: 4,
    all: 5
};
function rainwave(_message_1, _settings_1, _a, radio_1) {
    return __awaiter(this, arguments, void 0, function* (_message, _settings, { request }, radio, ...formatted) {
        var _b, _c, _d, _e;
        let radioId = RadioMap[radio === null || radio === void 0 ? void 0 : radio.toLowerCase()];
        if (radioId == null) {
            radioId = RadioMap.all;
        }
        const reqOpts = {
            sid: radioId,
        };
        const req = yield (0, helpers_1.httpRequest)(request, `https://rainwave.cc/api4/info?${(0, querystring_1.stringify)(reqOpts)}`);
        if (req == null || (0, lodash_1.isString)(req)) {
            return `[Error: Unable to fetch radio info]`;
        }
        const current = (_c = (_b = req.sched_current) === null || _b === void 0 ? void 0 : _b.songs) === null || _c === void 0 ? void 0 : _c[0];
        if (current == null) {
            return `[Error: No song found]`;
        }
        const artists = (_d = current.artists) === null || _d === void 0 ? void 0 : _d.map(artist => artist.name);
        const albums = (_e = current.albums) === null || _e === void 0 ? void 0 : _e.map(album => album.name);
        const url = current.url || '';
        if (formatted != null && formatted.length > 0) {
            return formatted.join(' ')
                .replace(/#title/g, current.title)
                .replace(/#artist/g, artists === null || artists === void 0 ? void 0 : artists.join(', '))
                .replace(/#album/g, albums === null || albums === void 0 ? void 0 : albums.join(', '))
                .replace(/#url/g, url);
        }
        return `${current.title} by ${artists === null || artists === void 0 ? void 0 : artists.join(', ')} on ${albums === null || albums === void 0 ? void 0 : albums.join(', ')}${url === '' ? '' : ' - '}`;
    });
}
//# sourceMappingURL=rainwave.js.map