"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.uptime = uptime;
const config = require("config");
const countdown = require("countdown");
const moment = require("moment");
const helpers_1 = require("../lib/helpers");
const providers = {
    trovo: (_parser, request, channelId, _coreId, _serviceId) => __awaiter(void 0, void 0, void 0, function* () {
        const reqHeaders = {
            Accept: 'application/json',
            'Client-ID': config.get('providers.trovo.clientId'),
        };
        const reqBody = {};
        if (isNaN(Number(channelId))) {
            reqBody['username'] = channelId;
        }
        else {
            reqBody['channel_id'] = channelId;
        }
        const res = yield (0, helpers_1.httpRequest)(request, `${config.get('providers.trovo.urls.api')}/openplatform/channels/id`, { headers: reqHeaders, method: 'POST', body: JSON.stringify(reqBody) });
        if (res == null || res['is_live'] === false || Number(res['started_at']) < 1) {
            return '[Channel Offline]';
        }
        return countdown(new Date(), moment(new Date(Number(res['started_at']) * 1000)).toDate());
    }),
    twitch: (parser, _request, channelId, coreId, serviceId) => __awaiter(void 0, void 0, void 0, function* () {
        const res = yield parser.middleware.onServiceAPI(`${config.get('providers.twitch.urls.api')}/helix/streams?user_id=${channelId}`, {
            coreId,
            method: 'GET',
            serviceId,
        });
        if (res == null || res.data.length === 0) {
            return '[Channel Offline]';
        }
        return countdown(new Date(), moment(res.data[0].started_at).toDate());
    }),
    picarto: (_parser, request, channelId, coreId, serviceId) => __awaiter(void 0, void 0, void 0, function* () {
        let uri = null;
        if (isNaN(Number(channelId))) {
            uri = `${config.get('providers.picarto.urls.api')}/api/v1/channel/name/${channelId}`;
        }
        else {
            uri = `${config.get('providers.picarto.urls.api')}/api/v1/channel/id/${channelId}`;
        }
        const res = yield (0, helpers_1.httpRequest)(request, uri);
        if (res == null || res['online'] === false || res['last_live'] == null) {
            return '[Channel Offline]';
        }
        return countdown(new Date(), moment(new Date(res['last_live'])).toDate());
    }),
    kick: (_parser, request, channelId, coreId, serviceId) => __awaiter(void 0, void 0, void 0, function* () {
        const headers = {
            'Content-Type': 'application/json',
            'Accept': 'application/json',
        };
        const res = yield (0, helpers_1.httpRequest)(request, `${config.get('providers.kick.urls.api')}/v1/channels/${String(channelId).toUpperCase()}`, { headers });
        if (res == null || res.livestream == null) {
            return '[Channel Offline]';
        }
        return countdown(new Date(), moment(res.livestream.created_at).toDate());
    }),
};
function uptime(message, _settings, { request }, channelId = message.channel.id) {
    if (providers[message.provider.toLowerCase()] == null) {
        return '[Invalid Provider]';
    }
    return providers[message.provider.toLowerCase()](this, request, channelId, message.channel.coreId, message.channel.serviceId);
}
//# sourceMappingURL=uptime.js.map