"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.urlfetch = urlfetch;
exports.urlfetchctx = urlfetchctx;
const config = require("config");
const lodash_1 = require("lodash");
const providerLengthLimit = {
    default: 300,
    discord: 2000,
};
const FETCH_TIMEOUT = 1000 * 15;
function urlfetch(message_1, settings_1, _a) {
    return __awaiter(this, arguments, void 0, function* (message, settings, { cache, request }, ...args) {
        var _b;
        const workerUri = config.get('urlfetch.workerUri');
        if (workerUri == null) {
            return '[Error: Custom API Not Supported]';
        }
        const onlyContext = typeof args[0] === 'boolean' && args[0] === true;
        const customUrl = onlyContext ? args[1] : args[0];
        if (customUrl == null || customUrl.length < 1) {
            return '[Error: URL Missing]';
        }
        const pickOpts = onlyContext ? args[2] : args[1];
        let headers = Object.assign(Object.assign({}, ((_b = this.middleware) === null || _b === void 0 ? void 0 : _b.onGetHeaders) != null ? yield this.middleware.onGetHeaders(message) : {}), { 'Content-Type': 'application/json' });
        const payload = {
            method: 'GET',
            url: customUrl,
        };
        const controller = new AbortController();
        const abortTimeout = setTimeout(() => controller.abort(), FETCH_TIMEOUT);
        return request(workerUri, { body: JSON.stringify(payload), method: 'POST', headers, signal: controller.signal })
            .then((res) => __awaiter(this, void 0, void 0, function* () {
            clearTimeout(abortTimeout);
            const cloned = res.clone();
            const textData = yield cloned.text();
            try {
                const jsonData = JSON.parse(textData);
                if (onlyContext) {
                    cache.push(jsonData);
                    return '';
                }
                if (pickOpts == null || pickOpts.length < 1) {
                    return '[Error: Pick Option Missing]';
                }
                const jsonResult = (0, lodash_1.get)(jsonData, pickOpts);
                if (jsonResult == null) {
                    return '[Error: Pick Option Invalid]';
                }
                if ((0, lodash_1.isObject)(jsonResult)) {
                    return '[Error: Object Returns Disallowed]';
                }
                return String(jsonResult);
            }
            catch (_a) {
                const textLines = textData.split('\n');
                if (onlyContext) {
                    cache.push(textLines);
                    return '';
                }
                if (pickOpts == null || pickOpts.length < 1) {
                    return textLines[0];
                }
                if ((pickOpts === 'rand' || pickOpts === 'random')) {
                    return (0, lodash_1.sample)(textLines);
                }
                if (!isNaN(Number(pickOpts))) {
                    return textLines[Number(pickOpts)] || '[Error: Pick Option Invalid]';
                }
                return textLines[0];
            }
        }))
            .then(res => {
            if (res == null) {
                return '[Error: Failed to Parse Response]';
            }
            if (res.includes('urlfetch') || res.includes('urlfetchctx')) {
                return res;
            }
            return this.parse.call(this, message, settings, res);
        })
            .then(res => (0, lodash_1.truncate)(String(res), { length: providerLengthLimit[message.provider] || providerLengthLimit.default }))
            .catch(() => {
            clearTimeout(abortTimeout);
            return null;
        });
    });
}
function urlfetchctx(message, _settings, { request, cache }, ...args) {
    const newArgs = [true, ...args];
    return urlfetch.call(this, message, _settings, { request, cache }, ...newArgs);
}
//# sourceMappingURL=urlfetch.js.map