"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.weather = weather;
const config = require("config");
const lodash_1 = require("lodash");
const querystring_1 = require("querystring");
const helpers_1 = require("../lib/helpers");
const directions = [
    'North',
    'North (North-East)',
    'North East',
    'East (North-East)',
    'East',
    'East (South-East)',
    'South East',
    'South (South-East)',
    'South',
    'South (South-West)',
    'South West',
    'West (South-West)',
    'West',
    'West (North-West)',
    'North West',
    'North (North-West)',
];
const getDirection = (deg) => directions[(Math.floor(0.5 + (deg / 22.5)) % 16)];
const getTemp = (temp) => `${temp.toFixed(2)} °C (${Number(temp * 9 / 5 + 32).toFixed(2)} °F)`;
function weather(_message_1, _settings_1, _a, region_1) {
    return __awaiter(this, arguments, void 0, function* (_message, _settings, { request }, region) {
        const reqOpts = {
            appid: config.get('parser.weather.key'),
            q: region,
            units: 'metric',
        };
        const req = yield (0, helpers_1.httpRequest)(request, `${config.get('parser.weather.base')}?${(0, querystring_1.stringify)(reqOpts)}`);
        if (req === undefined || (0, lodash_1.isString)(req)) {
            return '[Error: API Error]';
        }
        const { main, sys, wind } = req;
        if (sys.country == null) {
            return '[Error: Invalid Region]';
        }
        return `${req.name}, ${sys.country}: ${getTemp(main.temp)}. Feels like ${getTemp(main.feels_like)}. Wind is blowing from the ${getDirection(wind.deg)}. ${main.humidity}% humidity. Air pressure: ~${main.pressure} hPa.`;
    });
}
//# sourceMappingURL=weather.js.map